from ixnetwork_restpy.base import Base
from ixnetwork_restpy.files import Files


class AuxiliaryConnectionList(Base):
	"""The AuxiliaryConnectionList class encapsulates a system managed auxiliaryConnectionList node in the ixnetwork hierarchy.

	An instance of the class can be obtained by accessing the AuxiliaryConnectionList property from a parent instance.
	The internal properties list will be empty when the property is accessed and is populated from the server by using the find method.
	"""

	_SDM_NAME = 'auxiliaryConnectionList'

	def __init__(self, parent):
		super(AuxiliaryConnectionList, self).__init__(parent)

	@property
	def Active(self):
		"""Activate/Deactivate Configuration

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('active')

	@property
	def AuxId(self):
		"""Specify the Auxiliary Id, {0 - 255}

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('auxId')

	@property
	def ChannelName(self):
		"""Parent Channel Name

		Returns:
			str
		"""
		return self._get_attribute('channelName')

	@property
	def ConnectionType(self):
		"""The type of connection used for the Interface. Options include: 1) TCP 2) TLS 3) UDP

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('connectionType')

	@property
	def Count(self):
		"""Number of elements inside associated multiplier-scaled container object, e.g. number of devices inside a Device Group

		Returns:
			number
		"""
		return self._get_attribute('count')

	@property
	def DescriptiveName(self):
		"""Longer, more descriptive name for element. It's not guaranteed to be unique like -name-, but maybe offers more context

		Returns:
			str
		"""
		return self._get_attribute('descriptiveName')

	@property
	def Name(self):
		"""Name of NGPF element, guaranteed to be unique in Scenario

		Returns:
			str
		"""
		return self._get_attribute('name')
	@Name.setter
	def Name(self, value):
		self._set_attribute('name', value)

	@property
	def UDPSrcPortNum(self):
		"""UDP Source Port Number

		Returns:
			obj(ixnetwork_restpy.multivalue.Multivalue)
		"""
		return self._get_attribute('uDPSrcPortNum')

	def find(self, ChannelName=None, Count=None, DescriptiveName=None, Name=None):
		"""Finds and retrieves auxiliaryConnectionList data from the server.

		All named parameters support regex and can be used to selectively retrieve auxiliaryConnectionList data from the server.
		By default the find method takes no parameters and will retrieve all auxiliaryConnectionList data from the server.

		Args:
			ChannelName (str): Parent Channel Name
			Count (number): Number of elements inside associated multiplier-scaled container object, e.g. number of devices inside a Device Group
			DescriptiveName (str): Longer, more descriptive name for element. It's not guaranteed to be unique like -name-, but maybe offers more context
			Name (str): Name of NGPF element, guaranteed to be unique in Scenario

		Returns:
			self: This instance with found auxiliaryConnectionList data from the server available through an iterator or index

		Raises:
			ServerError: The server has encountered an uncategorized error condition
		"""
		return self._select(locals())
